@@ -131,7 +131,7 @@ When an error happens, a message is printed about the error.
 __author__ = "Nilton Volpato"
 __author_email__ = "nilton dot volpato | gmail com"
 __date__ = "2008-03-26"
-__version__ = "0.1.1a"
+__version__ = "0.1.2a"
 
 # TODO:
 #   - add support for short options to the parser
@@ -140,13 +140,42 @@ __version__ = "0.1.1a"
 #
 # 2008-03-26: v0.1a first public version
 # 2008-05-23: v0.1.1a removed external dependency of odict
+# 2008-05-27: v0.1.2a implemented a simple odict
 
 import inspect
 import os
 import sys
 import textwrap
-from odict import odict
 
+class odict(object):
+    "handicapped version of an ordered dict, but useful for our purposes"
+    def __init__(self):
+        self._dict = {}
+        self._keys = []
+    def __getitem__(self, key):
+        return self._dict[key]
+    def __setitem__(self, key, val):
+        if key not in self._dict:
+            self._keys.append(key)
+        self._dict[key] = val
+    def __contains__(self, key):
+        return key in self._dict
+    def iterkeys(self):
+        return iter(self._keys)
+    def keys(self):
+        return self._keys
+    def itervalues(self):
+        for key in self.iterkeys():
+            yield self._dict[key]
+    def values(self):
+        return list(self.itervalues())
+    def iteritems(self):
+        for key in self.iterkeys():
+            yield key, self._dict[key]
+    def items(self):
+        return list(self.iteritems())
+    def __iter__(self):
+        return self.iterkeys()
 
 def annotation(**ann):
     def decorate(f):
